"use client";

import DataTable from "@/components/tables/DataTable";
import { DeleteIcon } from "@chakra-ui/icons";
import { Button, Flex, Icon, useColorModeValue, useToast } from "@chakra-ui/react";
import { columnsDataAdminBlocks, columnsDataClubBlocks } from "../variables/columnsBlock";
import { TableData } from "@/variables/columnsData";
import { useRouter } from "next/navigation";
import { FaUserMinus, FaUserPlus } from "react-icons/fa6";
import { updateClubRequest, updateRequest } from "@/app/lib/request/action";
import { AdminRequestInterface, ClubRequestInterface, RequestInterface } from "../type/request";

export default function RequestTable({ data, role }: { data: RequestInterface[]; role: any }) {
  const brandColor = useColorModeValue("brand.500", "white");
  const usersList = role?.id !== 1 ? data.filter((x) => {
    return x.status == "pending";
  }) : data ;
  const columns = role?.id !== 1 ? columnsDataClubBlocks : columnsDataAdminBlocks;

  const toast = useToast();
  const router = useRouter();

  const updateUser = async (id: number, status: string) => {
    const payload: ClubRequestInterface | AdminRequestInterface =
      role?.id !== 1 && status !== "rejected"
        ? {
            id: usersList[id]._id,
            status: status,
          }
        : {
            userId: usersList[id]._id,
            status: status,
          };
    const res = role?.id !== 1 && status !== "rejected" ? await updateClubRequest(payload as ClubRequestInterface) : await updateRequest(payload as AdminRequestInterface);
    
    toast({
      title: "200",
      description: res.message,
      status: "success",
      position: "top-right",
      duration: 2000,
      isClosable: true,
    });
    router.refresh();
  };

  const action = (id: number) => (
    <Flex gap={2}>
      <Button
        variant="blank"
        alignItems="center"
        justifyContent="center"
        w="37px"
        h="37px"
        lineHeight="100%"
        borderRadius="10px"
        onClick={() => {
          updateUser(id, role?.id == 1 ? "active" : "joined");
        }}>
        <Icon as={FaUserPlus} color={brandColor} w="20px" h="20px" />
      </Button>
      <Button
        variant="blank"
        alignItems="center"
        justifyContent="center"
        w="37px"
        h="37px"
        lineHeight="100%"
        borderRadius="10px"
        onClick={() => {
          updateUser(id, "rejected");
        }}>
        <Icon as={FaUserMinus} color={brandColor} w="20px" h="20px" />
      </Button>
    </Flex>
  );

  return (
    <>
      <DataTable columnsData={columns} tableData={usersList as unknown as TableData[]} isSelectable={false} showPageSize={false} actionSlot={action} />
    </>
  );
}
